﻿;/////////////////////////////////////////////////////////////////////////////////
;Demo of the OOP class for implementing memory files.

;By Stephen Rodriguez.

;This demo program shows how to create a memory file object from an existing memory buffer using the new
;NewMemoryFileFromMemoryBuffer() function.
;
;Such functionality is useful for creating a memory file object, for example, from data received from a network connection
;(which is why I have introduced this new functionality!)
;One thing to note is that the pre-existing buffer, if containing strings, then those strings must be zero terminated.
;/////////////////////////////////////////////////////////////////////////////////

XIncludeFile "memoryFileClass.pbi"


;Create a memory buffer to simulate one received from a network (for example).
;When we pass this buffer to the memoryFileClass library, then the buffer belongs to the lib. DO NOT attempt to free this memory.
  *buffer = AllocateMemory(40)
  If *buffer = 0
    MessageRequester("Error :", "There was a memory allocation problem.")
    End
  EndIf
  ;Add some data. We add 10 long values; 1, 2, ... 10.
    *ptrLong.LONG = *buffer
    For i = 1 To 10
      *ptrLong\l = i
      *ptrLong + SizeOf(LONG)
    Next

;Create a MemoryFile object with initial size 100 bytes and page size 50 bytes.

   MyMemoryFileObject.MemoryFileObject
   MyMemoryFileObject = NewMemoryFileFromMemoryBuffer(*buffer, 40, 50)


If MyMemoryFileObject ;Always check that the object was created successfully.

  ;Take a look how much data there is in the object (this should report 40 bytes).
    count = MyMemoryFileObject\Lof()
    Debug "Written " + Str(count) + " bytes in total."
    Debug "==================="

  ;Let us take a look at the data.
    Debug "Data written ....."
      While MyMemoryFileObject\Eof() = 0
        Debug "   " + Str(MyMemoryFileObject\ReadLong())
      Wend
    Debug "==================="
    Debug ""

  ;Destroy the array once it is no longer required.
  ;By not setting the optional parameter to #False, we are opting to free the memory buffer itself (on top of deleting the object).
  ;This means that under no circumstances should we issue a FreeMemory() call ourselves.

    MyMemoryFileObject\Destroy()

Else
  MessageRequester("Error :", "There was a memory allocation problem creating the memory buffer object.")
EndIf



; IDE Options = PureBasic 4.61 Beta 1 (Windows - x86)
; CursorPosition = 33
; FirstLine = 22
; EnableAsm
; EnableUnicode